// /qt/qml/org/kde/desktop/private/DefaultSliderHandle.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qalgorithms.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qrandom.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <cmath>
#include <limits>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_kde_desktop_private_DefaultSliderHandle_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x4a,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x70,0xe,0x0,0x0,0xe8,0x1d,0x8,0x2c,
0x67,0x45,0x2c,0xa9,0x75,0x24,0x77,0x5,
0xd1,0xdd,0xbf,0xcd,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x2c,0x0,0x0,0x0,0xc8,0x5,0x0,0x0,
0x9,0x0,0x0,0x0,0xc8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xec,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xec,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0xec,0x0,0x0,0x0,
0x30,0x0,0x0,0x0,0xf0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xb0,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0xc,0x0,0x0,
0xb0,0x1,0x0,0x0,0x40,0x2,0x0,0x0,
0xe8,0x2,0x0,0x0,0x70,0x3,0x0,0x0,
0xf8,0x3,0x0,0x0,0x48,0x4,0x0,0x0,
0x98,0x4,0x0,0x0,0xe8,0x4,0x0,0x0,
0x48,0x5,0x0,0x0,0xb8,0x5,0x0,0x0,
0x93,0x0,0x0,0x0,0xe0,0x1,0x0,0x0,
0x43,0x0,0x0,0x0,0xf0,0x1,0x0,0x0,
0xb3,0x0,0x0,0x0,0xb3,0x0,0x0,0x0,
0x4,0x2,0x0,0x0,0x13,0x2,0x0,0x0,
0x20,0x2,0x0,0x0,0x30,0x2,0x0,0x0,
0xd4,0x0,0x0,0x0,0x93,0x0,0x0,0x0,
0x40,0x2,0x0,0x0,0x53,0x2,0x0,0x0,
0x93,0x0,0x0,0x0,0x70,0x2,0x0,0x0,
0x93,0x0,0x0,0x0,0x80,0x2,0x0,0x0,
0x93,0x0,0x0,0x0,0x90,0x2,0x0,0x0,
0x23,0x2,0x0,0x0,0x93,0x0,0x0,0x0,
0x90,0x2,0x0,0x0,0x23,0x2,0x0,0x0,
0x64,0x2,0x0,0x0,0x93,0x0,0x0,0x0,
0xa0,0x2,0x0,0x0,0x53,0x2,0x0,0x0,
0x93,0x0,0x0,0x0,0x70,0x2,0x0,0x0,
0x93,0x0,0x0,0x0,0xb0,0x2,0x0,0x0,
0x33,0x2,0x0,0x0,0x93,0x0,0x0,0x0,
0x80,0x2,0x0,0x0,0x93,0x0,0x0,0x0,
0xb0,0x2,0x0,0x0,0x33,0x2,0x0,0x0,
0x64,0x2,0x0,0x0,0xd3,0x0,0x0,0x0,
0x20,0x2,0x0,0x0,0xd3,0x0,0x0,0x0,
0x30,0x2,0x0,0x0,0x73,0x0,0x0,0x0,
0xb0,0x0,0x0,0x0,0x73,0x0,0x0,0x0,
0xe4,0x0,0x0,0x0,0xe7,0x0,0x0,0x0,
0x68,0x0,0x0,0x0,0x1d,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x4,0x0,
0xff,0xff,0xff,0xff,0x9,0x0,0x0,0x0,
0x10,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x12,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x1a,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x1,0x2,0x7,0x1,0x2e,0x0,0x3c,0x1,
0x18,0x7,0x18,0x8,0x2e,0x2,0x3c,0x3,
0x72,0x8,0x50,0x4,0x16,0x7,0x4c,0x1,
0xc,0x2,0x16,0x6,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x74,0x0,0x0,0x0,0x30,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x5,0x0,
0xff,0xff,0xff,0xff,0xd,0x0,0x0,0x0,
0x19,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1a,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x1a,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x1b,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x17,0x0,0x0,0x0,
0x1c,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x2e,0x0,0x0,0x0,0x1e,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x2e,0x4,0x50,0x2a,
0x1,0x2,0x7,0x1,0x2e,0x5,0x18,0x8,
0x12,0x7,0x18,0xb,0xac,0x6,0x8,0x1,
0xb,0x18,0x7,0x2e,0x7,0x18,0x8,0x16,
0x7,0x3c,0x8,0x18,0xb,0x16,0x7,0x3c,
0x9,0x18,0xc,0xac,0xa,0x8,0x2,0xb,
0x30,0xd,0xe,0x2,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x40,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x10,0x0,0x0,0x0,
0x20,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0xb,0x3c,0xc,
0x18,0x7,0x2e,0xd,0x18,0x8,0x2e,0xe,
0x3c,0xf,0x50,0x14,0x2e,0x10,0x3c,0x11,
0x18,0xc,0x2e,0x12,0x3c,0x13,0x18,0xd,
0x2e,0x14,0xa2,0xd,0x9c,0xc,0x4c,0x10,
0x2e,0x15,0x3c,0x16,0x18,0xe,0x2e,0x17,
0xa2,0xe,0x18,0xf,0x10,0x2,0x9e,0xf,
0x18,0xb,0xac,0x18,0x8,0x1,0xb,0x80,
0x7,0x18,0x6,0x2,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x40,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x10,0x0,0x0,0x0,
0x21,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x21,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x19,0x3c,0x1a,
0x18,0x7,0x2e,0x1b,0x18,0x8,0x2e,0x1c,
0x3c,0x1d,0x50,0x12,0x2e,0x1e,0x3c,0x1f,
0x18,0xc,0x2e,0x20,0xa2,0xc,0x18,0xd,
0x10,0x2,0x9e,0xd,0x4c,0x12,0x2e,0x21,
0x3c,0x22,0x18,0xe,0x2e,0x23,0x3c,0x24,
0x18,0xf,0x2e,0x25,0xa2,0xf,0x9c,0xe,
0x18,0xb,0xac,0x26,0x8,0x1,0xb,0x80,
0x7,0x18,0x6,0x2,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x23,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x27,0x3c,0x28,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x24,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x24,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x29,0x3c,0x2a,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x19,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x27,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x27,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x2b,0x3c,0x2c,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x50,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0x1a,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0x29,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2a,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x2b,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x2e,0x2d,0x18,0x7,0xac,0x2e,0x7,0x0,
0x0,0xe,0x2,0x0,0x0,0x0,0x0,0x0,
0x5c,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0x1d,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x3,0x0,
0xff,0xff,0xff,0xff,0x9,0x0,0x0,0x0,
0x2e,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2e,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x2f,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x30,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0xca,0xb4,0x2f,0x0,
0x0,0x18,0x6,0xd4,0x16,0x6,0x2,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x78,0x6,0x0,0x0,0x80,0x6,0x0,0x0,
0x98,0x6,0x0,0x0,0xa0,0x6,0x0,0x0,
0xc8,0x6,0x0,0x0,0xe8,0x6,0x0,0x0,
0x30,0x7,0x0,0x0,0x40,0x7,0x0,0x0,
0x58,0x7,0x0,0x0,0x70,0x7,0x0,0x0,
0x88,0x7,0x0,0x0,0xc0,0x7,0x0,0x0,
0xd8,0x7,0x0,0x0,0x10,0x8,0x0,0x0,
0x20,0x8,0x0,0x0,0x48,0x8,0x0,0x0,
0x50,0x8,0x0,0x0,0x78,0x8,0x0,0x0,
0x80,0x8,0x0,0x0,0xa8,0x8,0x0,0x0,
0xc8,0x8,0x0,0x0,0x8,0x9,0x0,0x0,
0x30,0x9,0x0,0x0,0x70,0x9,0x0,0x0,
0x90,0x9,0x0,0x0,0xa8,0x9,0x0,0x0,
0xd8,0x9,0x0,0x0,0x8,0xa,0x0,0x0,
0x20,0xa,0x0,0x0,0x40,0xa,0x0,0x0,
0x80,0xa,0x0,0x0,0xa0,0xa,0x0,0x0,
0xb8,0xa,0x0,0x0,0xe0,0xa,0x0,0x0,
0xf0,0xa,0x0,0x0,0x0,0xb,0x0,0x0,
0x18,0xb,0x0,0x0,0x38,0xb,0x0,0x0,
0x48,0xb,0x0,0x0,0x58,0xb,0x0,0x0,
0x78,0xb,0x0,0x0,0xa0,0xb,0x0,0x0,
0xc8,0xb,0x0,0x0,0xe8,0xb,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x2e,0x0,0x54,0x0,0x65,0x0,
0x6d,0x0,0x70,0x0,0x6c,0x0,0x61,0x0,
0x74,0x0,0x65,0x0,0x73,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x53,0x0,0x74,0x0,
0x79,0x0,0x6c,0x0,0x65,0x0,0x50,0x0,
0x72,0x0,0x69,0x0,0x76,0x0,0x61,0x0,
0x74,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0x20,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x71,0x0,0x71,0x0,
0x63,0x0,0x32,0x0,0x64,0x0,0x65,0x0,
0x73,0x0,0x6b,0x0,0x74,0x0,0x6f,0x0,
0x70,0x0,0x73,0x0,0x74,0x0,0x79,0x0,
0x6c,0x0,0x65,0x0,0x2e,0x0,0x70,0x0,
0x72,0x0,0x69,0x0,0x76,0x0,0x61,0x0,
0x74,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x49,0x0,0x74,0x0,
0x65,0x0,0x6d,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x68,0x0,0x61,0x0,
0x6e,0x0,0x64,0x0,0x6c,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x54,0x0,0x2e,0x0,
0x53,0x0,0x6c,0x0,0x69,0x0,0x64,0x0,
0x65,0x0,0x72,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x6e,0x0,0x74,0x0,0x72,0x0,0x6f,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x53,0x0,0x74,0x0,
0x79,0x0,0x6c,0x0,0x65,0x0,0x50,0x0,
0x72,0x0,0x69,0x0,0x76,0x0,0x61,0x0,
0x74,0x0,0x65,0x0,0x2e,0x0,0x53,0x0,
0x74,0x0,0x79,0x0,0x6c,0x0,0x65,0x0,
0x49,0x0,0x74,0x0,0x65,0x0,0x6d,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x73,0x0,0x74,0x0,
0x79,0x0,0x6c,0x0,0x65,0x0,0x49,0x0,
0x74,0x0,0x65,0x0,0x6d,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x73,0x0,0x74,0x0,0x79,0x0,
0x6c,0x0,0x65,0x0,0x49,0x0,0x74,0x0,
0x65,0x0,0x6d,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x73,0x0,0x69,0x0,
0x7a,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x75,0x0,0x70,0x0,
0x64,0x0,0x61,0x0,0x74,0x0,0x65,0x0,
0x48,0x0,0x61,0x0,0x6e,0x0,0x64,0x0,
0x6c,0x0,0x65,0x0,0x53,0x0,0x69,0x0,
0x7a,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x78,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x78,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x79,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x79,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x69,0x0,0x74,0x0,0x57,0x0,0x69,0x0,
0x64,0x0,0x74,0x0,0x68,0x0,0x0,0x0,
0x1c,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x69,0x0,0x6d,0x0,0x70,0x0,
0x6c,0x0,0x69,0x0,0x63,0x0,0x69,0x0,
0x74,0x0,0x57,0x0,0x69,0x0,0x64,0x0,
0x74,0x0,0x68,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x69,0x0,0x6d,0x0,
0x70,0x0,0x6c,0x0,0x69,0x0,0x63,0x0,
0x69,0x0,0x74,0x0,0x48,0x0,0x65,0x0,
0x69,0x0,0x67,0x0,0x68,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1d,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x69,0x0,0x6d,0x0,0x70,0x0,
0x6c,0x0,0x69,0x0,0x63,0x0,0x69,0x0,
0x74,0x0,0x48,0x0,0x65,0x0,0x69,0x0,
0x67,0x0,0x68,0x0,0x74,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x43,0x0,0x6f,0x0,
0x6e,0x0,0x6e,0x0,0x65,0x0,0x63,0x0,
0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x73,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x74,0x0,0x61,0x0,
0x72,0x0,0x67,0x0,0x65,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x74,0x0,0x61,0x0,0x72,0x0,
0x67,0x0,0x65,0x0,0x74,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x53,0x0,0x74,0x0,0x79,0x0,0x6c,0x0,
0x65,0x0,0x4e,0x0,0x61,0x0,0x6d,0x0,
0x65,0x0,0x43,0x0,0x68,0x0,0x61,0x0,
0x6e,0x0,0x67,0x0,0x65,0x0,0x64,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x43,0x0,0x6f,0x0,
0x6d,0x0,0x70,0x0,0x6f,0x0,0x6e,0x0,
0x65,0x0,0x6e,0x0,0x74,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x43,0x0,0x6f,0x0,0x6d,0x0,0x70,0x0,
0x6c,0x0,0x65,0x0,0x74,0x0,0x65,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1a,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x6e,0x0,0x43,0x0,
0x6f,0x0,0x6d,0x0,0x70,0x0,0x6c,0x0,
0x65,0x0,0x74,0x0,0x65,0x0,0x64,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x62,0x0,0x61,0x0,
0x63,0x0,0x6b,0x0,0x67,0x0,0x72,0x0,
0x6f,0x0,0x75,0x0,0x6e,0x0,0x64,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x53,0x0,0x74,0x0,
0x79,0x0,0x6c,0x0,0x65,0x0,0x49,0x0,
0x74,0x0,0x65,0x0,0x6d,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x73,0x0,0x75,0x0,
0x62,0x0,0x43,0x0,0x6f,0x0,0x6e,0x0,
0x74,0x0,0x72,0x0,0x6f,0x0,0x6c,0x0,
0x52,0x0,0x65,0x0,0x63,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x77,0x0,0x69,0x0,
0x64,0x0,0x74,0x0,0x68,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x68,0x0,0x65,0x0,
0x69,0x0,0x67,0x0,0x68,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x6c,0x0,0x65,0x0,
0x66,0x0,0x74,0x0,0x50,0x0,0x61,0x0,
0x64,0x0,0x64,0x0,0x69,0x0,0x6e,0x0,
0x67,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x4d,0x0,0x61,0x0,
0x74,0x0,0x68,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x72,0x0,0x6f,0x0,
0x75,0x0,0x6e,0x0,0x64,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x68,0x0,0x6f,0x0,
0x72,0x0,0x69,0x0,0x7a,0x0,0x6f,0x0,
0x6e,0x0,0x74,0x0,0x61,0x0,0x6c,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x76,0x0,0x69,0x0,
0x73,0x0,0x75,0x0,0x61,0x0,0x6c,0x0,
0x50,0x0,0x6f,0x0,0x73,0x0,0x69,0x0,
0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x61,0x0,0x76,0x0,
0x61,0x0,0x69,0x0,0x6c,0x0,0x61,0x0,
0x62,0x0,0x6c,0x0,0x65,0x0,0x57,0x0,
0x69,0x0,0x64,0x0,0x74,0x0,0x68,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x74,0x0,0x6f,0x0,
0x70,0x0,0x50,0x0,0x61,0x0,0x64,0x0,
0x64,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x61,0x0,0x76,0x0,
0x61,0x0,0x69,0x0,0x6c,0x0,0x61,0x0,
0x62,0x0,0x6c,0x0,0x65,0x0,0x48,0x0,
0x65,0x0,0x69,0x0,0x67,0x0,0x68,0x0,
0x74,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x4c,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x7,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x8,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x1,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x9,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x58,0x0,0x0,0x0,
0x80,0x1,0x0,0x0,0xf0,0x1,0x0,0x0,
0x6,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x1,0x0,0x3,0x0,0x54,0x0,0x0,0x0,
0x58,0x0,0x0,0x0,0x7c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x7c,0x0,0x0,0x0,
0x7c,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x7c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x24,0x1,0x0,0x0,0xb,0x0,0x10,0x0,
0xc,0x0,0x50,0x0,0x24,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x24,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x8,0x0,0x0,0x10,
0xe,0x0,0x50,0x0,0xb,0x0,0x0,0x0,
0xa,0x0,0x0,0x80,0x10,0x0,0x50,0x0,
0xd,0x0,0x0,0x0,0xd,0x0,0x0,0x20,
0x17,0x0,0x50,0x0,0x15,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x5,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x24,0x0,0x50,0x0,
0x24,0x0,0x50,0x1,0x13,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x50,0x0,
0x23,0x0,0x40,0x1,0x11,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x3,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x21,0x0,0x50,0x0,
0x21,0x0,0x80,0x0,0xf,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x0,0x50,0x0,
0x20,0x0,0x80,0x0,0xb,0x0,0x0,0x0,
0x8,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0xe0,0x2,
0x10,0x0,0x90,0x3,0x0,0x0,0x0,0x0,
0x0,0x0,0x8,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x26,0x0,0x50,0x0,
0x26,0x0,0x50,0x0,0x1b,0x0,0x0,0x0,
0x0,0x0,0x9,0x0,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2e,0x0,0x50,0x0,
0x2e,0x0,0xf0,0x0,0x0,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x1,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x58,0x0,0x0,0x0,0x58,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x58,0x0,0x0,0x0,
0x58,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0x58,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x70,0x0,0x0,0x0,0x26,0x0,0x50,0x0,
0x0,0x0,0x0,0x0,0x70,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x70,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x6,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x27,0x0,0x90,0x0,0x27,0x0,0x10,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x2e,0x0,0x50,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1c,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2e,0x0,0xf0,0x0,
0x2e,0x0,0xc0,0x1,0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 2, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for x at line 32, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_10, markStack);
    aotContext->mark(v2_16, markStack);
    aotContext->mark(v2_22, markStack);
    aotContext->mark(v2_36, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QObject *v2_10 = nullptr;
QObject *v2_16 = nullptr;
QObject *v2_22 = nullptr;
QObject *v2_36 = nullptr;
bool v2_12;
double v11_52;
double v2_18;
double v2_24;
double v2_28;
double v2_2;
double v2_30;
double v2_32;
double v2_38;
double v2_42;
double v2_44;
double v2_48;
double v2_50;
double v2_54;
double v2_59;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(11, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadScopeObjectPropertyLookup(11);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(12, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(12, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
{
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(14, &s.v2_10)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
aotContext->initLoadScopeObjectPropertyLookup(14);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
while (!aotContext->getObjectLookup(15, s.v2_10, &s.v2_12)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
aotContext->initGetObjectLookup(15, s.v2_10);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_JumpFalse
if (!s.v2_12) {
    goto label_0;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(16, &s.v2_16)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
aotContext->initLoadScopeObjectPropertyLookup(16);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(20);
#endif
while (!aotContext->getObjectLookup(17, s.v2_16, &s.v2_18)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(20);
#endif
aotContext->initGetObjectLookup(17, s.v2_16);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(24);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(18, &s.v2_22)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(24);
#endif
aotContext->initLoadScopeObjectPropertyLookup(18);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(26);
#endif
while (!aotContext->getObjectLookup(19, s.v2_22, &s.v2_24)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(26);
#endif
aotContext->initGetObjectLookup(19, s.v2_22);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(30);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(20, &s.v2_28)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(30);
#endif
aotContext->initLoadScopeObjectPropertyLookup(20);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Sub
s.v2_30 = (s.v2_24 - s.v2_28);
{
}
// generate_Mul
s.v2_32 = (s.v2_18 * s.v2_30);
{
}
// generate_Jump
{
s.v11_52 = s.v2_32;
    goto label_1;
}
label_0:;
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(38);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(21, &s.v2_36)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(38);
#endif
aotContext->initLoadScopeObjectPropertyLookup(21);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(40);
#endif
while (!aotContext->getObjectLookup(22, s.v2_36, &s.v2_38)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(40);
#endif
aotContext->initGetObjectLookup(22, s.v2_36);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(44);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(23, &s.v2_42)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(44);
#endif
aotContext->initLoadScopeObjectPropertyLookup(23);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Sub
s.v2_44 = (s.v2_38 - s.v2_42);
{
}
// generate_StoreReg
{
}
// generate_LoadInt
s.v2_48 = double(2);
{
}
// generate_Div
QT_WARNING_PUSH
QT_WARNING_DISABLE_MSVC(4723) // potential divide by 0
s.v2_50 = (s.v2_44 / s.v2_48);
QT_WARNING_POP
{
s.v11_52 = s.v2_50;
}
label_1:;
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
const double arg1 = s.v11_52;
s.v2_54 = std::isfinite(arg1) ? ((arg1 < 0.5 && arg1 >= -0.5) ? std::copysign(0.0, arg1) : std::floor(arg1 + 0.5)) : arg1;
}
{
}
// generate_Add
s.v2_59 = (s.v2_2 + s.v2_54);
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_59;
}
return;
}
 },{ 3, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for y at line 33, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_10, markStack);
    aotContext->mark(v2_16, markStack);
    aotContext->mark(v2_34, markStack);
    aotContext->mark(v2_40, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QObject *v2_10 = nullptr;
QObject *v2_16 = nullptr;
QObject *v2_34 = nullptr;
QObject *v2_40 = nullptr;
bool v2_12;
double v11_52;
double v2_18;
double v2_22;
double v2_24;
double v2_28;
double v2_2;
double v2_30;
double v2_36;
double v2_42;
double v2_46;
double v2_48;
double v2_50;
double v2_54;
double v2_59;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(25, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadScopeObjectPropertyLookup(25);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(26, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(26, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
{
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(28, &s.v2_10)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
aotContext->initLoadScopeObjectPropertyLookup(28);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
while (!aotContext->getObjectLookup(29, s.v2_10, &s.v2_12)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
aotContext->initGetObjectLookup(29, s.v2_10);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_JumpFalse
if (!s.v2_12) {
    goto label_0;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(30, &s.v2_16)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
aotContext->initLoadScopeObjectPropertyLookup(30);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(20);
#endif
while (!aotContext->getObjectLookup(31, s.v2_16, &s.v2_18)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(20);
#endif
aotContext->initGetObjectLookup(31, s.v2_16);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(24);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(32, &s.v2_22)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(24);
#endif
aotContext->initLoadScopeObjectPropertyLookup(32);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Sub
s.v2_24 = (s.v2_18 - s.v2_22);
{
}
// generate_StoreReg
{
}
// generate_LoadInt
s.v2_28 = double(2);
{
}
// generate_Div
QT_WARNING_PUSH
QT_WARNING_DISABLE_MSVC(4723) // potential divide by 0
s.v2_30 = (s.v2_24 / s.v2_28);
QT_WARNING_POP
{
}
// generate_Jump
{
s.v11_52 = s.v2_30;
    goto label_1;
}
label_0:;
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(36);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(33, &s.v2_34)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(36);
#endif
aotContext->initLoadScopeObjectPropertyLookup(33);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(38);
#endif
while (!aotContext->getObjectLookup(34, s.v2_34, &s.v2_36)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(38);
#endif
aotContext->initGetObjectLookup(34, s.v2_34);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(42);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(35, &s.v2_40)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(42);
#endif
aotContext->initLoadScopeObjectPropertyLookup(35);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(44);
#endif
while (!aotContext->getObjectLookup(36, s.v2_40, &s.v2_42)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(44);
#endif
aotContext->initGetObjectLookup(36, s.v2_40);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(48);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(37, &s.v2_46)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(48);
#endif
aotContext->initLoadScopeObjectPropertyLookup(37);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
// generate_Sub
s.v2_48 = (s.v2_42 - s.v2_46);
{
}
// generate_Mul
s.v2_50 = (s.v2_36 * s.v2_48);
{
s.v11_52 = s.v2_50;
}
label_1:;
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
const double arg1 = s.v11_52;
s.v2_54 = std::isfinite(arg1) ? ((arg1 < 0.5 && arg1 >= -0.5) ? std::copysign(0.0, arg1) : std::floor(arg1 + 0.5)) : arg1;
}
{
}
// generate_Add
s.v2_59 = (s.v2_2 + s.v2_54);
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_59;
}
return;
}
 },{ 4, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for implicitWidth at line 35, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QVariant v2_0;
double v2_2;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
s.v2_0 = QVariant(aotContext->lookupResultMetaType(39));
while (!aotContext->loadScopeObjectPropertyLookup(39, s.v2_0.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadScopeObjectPropertyLookup(39);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
s.v2_0 = QVariant(aotContext->lookupResultMetaType(39));
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getValueLookup(40, s.v2_0.data(), &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetValueLookup(40, []() { static const auto t = QMetaType::fromName("QQmlSizeFValueType"); return t; }().metaObject());
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_2;
}
return;
}
 },{ 5, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<double>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for implicitHeight at line 36, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QVariant v2_0;
double v2_2;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
s.v2_0 = QVariant(aotContext->lookupResultMetaType(41));
while (!aotContext->loadScopeObjectPropertyLookup(41, s.v2_0.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadScopeObjectPropertyLookup(41);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
s.v2_0 = QVariant(aotContext->lookupResultMetaType(41));
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getValueLookup(42, s.v2_0.data(), &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetValueLookup(42, []() { static const auto t = QMetaType::fromName("QQmlSizeFValueType"); return t; }().metaObject());
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<double *>(argv[0]) = double();
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<double *>(argv[0]) = s.v2_2;
}
return;
}
 },{ 6, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType::fromType<QObject *>();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for target at line 39, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_2, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QObject *v2_2 = nullptr;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(43, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(43);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QObject * *>(argv[0]) = nullptr;
}
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getObjectLookup(44, s.v2_0, &s.v2_2)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetObjectLookup(44, s.v2_0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QObject * *>(argv[0]) = nullptr;
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QObject * *>(argv[0]) = s.v2_2;
}
return;
}
 },{ 7, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// onStyleNameChanged at line 41, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
    aotContext->mark(v2_4, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
QVariant v2_4;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadContextIdLookup(45, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadContextIdLookup(45);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
QVariant callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult};
    return aotContext->callObjectPropertyLookup(46, s.v2_0, args, 0);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookup(46, s.v2_0, 1);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(9);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(9);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_4 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_4);
}
{
}
{
}
// generate_Ret
return;
}
 },{ 8, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for onCompleted at line 46, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_1, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QVariant v2_1;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_CreateCallContext
{
{
}
// generate_CallQmlContextPropertyLookup
{
QVariant callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult};
    return aotContext->callQmlContextPropertyLookup(47, args, 0);
};
const auto doInit = [&]() {
    aotContext->initCallQmlContextPropertyLookup(47, 1);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(5);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(5);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_1 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_1);
}
{
}
{
}
// generate_PopContext
{}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
